@@ -64,7 +64,7 @@ KS.apply(KS,
                 function(btn) {
                     if (btn !== 'yes' || !KS.isDefined(WorkspaceView)) return;
                     WorkspaceView.askLeavePage(false);
-                    KS.winvoke({ method: 'Logout', async: false, success: KS.esiaLogout });
+                    KS.winvoke({ method: 'Logout', success: KS.esiaLogout });
                 });
         },
 
@@ -471,11 +471,11 @@ KS.apply(KS,
                         //новый таймер на обновление
                         return setTimeout(this.doRefreshTokens.bind(this), response.ExpirationSeconds * 1000);
                     } else {
-                        return KS.winvoke({ method: 'Logout', async: false});
+                        return KS.winvoke({ method: 'Logout'});
                     }
                 },
                 error: () => {
-                    return KS.winvoke({ method: 'Logout', async: false});
+                    return KS.winvoke({ method: 'Logout'});
                 }
             });
 
@@ -1972,4 +1972,100 @@ KS.apply(KS,
         }
 
     };
+})();
+
+// ================= KS.Svod.ImageUtils ==================
+(function() {
+    KS.Svod.ImageUtils = {
+        downloadFromBase64: function(base64String, fileName) {
+            const link = document.createElement('a');
+            link.href = base64String;
+            link.download = fileName;
+
+            document.body.appendChild(link);
+            link.click();
+            document.body.removeChild(link);
+        },
+
+        printFromBase64: function(base64String, title) {
+            var printWindow = window.open('', '_blank');
+            title = title || 'Печать'
+
+            printWindow.document.write(`
+                <!DOCTYPE html>
+                <html>
+                <head>
+                    <title>${title}</title>
+                    <style>
+                        body {
+                            margin: 0;
+                            padding: 0;
+                            display: flex;
+                            justify-content: center;
+                            align-items: center;
+                            min-height: 100vh;
+                            background: white;
+                        }
+                        .image-container {
+                            text-align: center;
+                            page-break-inside: avoid;
+                        }
+                        img {
+                            max-width: 100%;
+                            max-height: 100vh;
+                            display: block;
+                            margin: 0 auto;
+                        }
+
+                        /* Стили для печати */
+                        @media print {
+                            body {
+                                padding: 0;
+                                margin: 0;
+                            }
+                            .no-print {
+                                display: none;
+                            }
+
+                            /* Принудительная горизонтальная ориентация */
+                            @page {
+                                size: landscape;
+                                margin: 0;
+                            }
+
+                            /* Гарантируем, что изображение займет всю страницу */
+                            img {
+                                max-width: 100vh;
+                                max-height: 100vw;
+                                width: auto;
+                                height: auto;
+                            }
+                        }
+
+                        /* Стили для предпросмотра на экране */
+                        @media screen {
+                            body {
+                                background: #f0f0f0;
+                            }
+                            img {
+                                box-shadow: 0 4px 8px rgba(0,0,0,0.3);
+                            }
+                        }
+                    </style>
+                </head>
+                <body>
+                    <div class="image-container">
+                        <img src="${base64String}" alt="Печатаемое изображение" onload="window.print()">
+                    </div>
+                    <div class="no-print" style="position: fixed; top: 10px; left: 10px;">
+                        <button onclick="window.print()">🖨️ Печать</button>
+                        <button onclick="window.close()">❌ Закрыть</button>
+                    </div>
+                </body>
+                </html>
+            `);
+
+            printWindow.document.close();
+        }
+    };
 })();
\ No newline at end of file
